oo_bindgen model for (extremely) limited FFI bindings to tokio.
Functions
- define
- Define all runtime related API artifacts and return a handle to the runtime class
- get_
impl_ file - Return the contents of the implementation file for the schema